from odoo import http
from odoo.http import request
import base64
import requests
from werkzeug.datastructures import FileStorage
import logging

_logger = logging.getLogger(__name__)


class RasdFormController(http.Controller):

    def verify_recaptcha(self, recaptcha_response, action_expected="submit"):
        """
        Verify reCAPTCHA v3 with Google.
        """
        secret_key = "6LfX9IwqAAAAAKVJ6umlbsKshCcTCDebLXc5ck2o"  # Replace with your reCAPTCHA secret key
        verify_url = "https://www.google.com/recaptcha/api/siteverify"
        payload = {
            'secret': secret_key,
            'response': recaptcha_response,
        }
        try:
            response = requests.post(verify_url, data=payload, timeout=10)
            result = response.json()
            if result.get('success') and result.get('action') == action_expected and result.get('score', 0) >= 0.5:
                return True
            return False
        except Exception as e:
            # Log error for debugging
            request.env['ir.logging'].sudo().create({
                'name': 'reCAPTCHA Verification',
                'type': 'server',
                'message': f"Error during reCAPTCHA verification: {str(e)}",
                'level': 'error',
            })
            return False

    def process_uploads(self, files, res_model, res_id):
        """
        Process and save uploaded files as ir.attachment records.
        """
        for file in files:
            if isinstance(file, FileStorage) and file.filename:
                request.env['ir.attachment'].sudo().create({
                    'name': file.filename,
                    'datas': base64.b64encode(file.read()).decode('utf-8'),
                    'res_model': res_model,
                    'res_id': res_id,
                    'type': 'binary',
                })

    @http.route('/rasd-forms', type='http', methods=['GET'], auth='public', website=True, csrf=False)
    def show_submission_form(self, **kwargs):
        """
        Display the submission form for visitors.
        """
        return request.render('rasd_forms.website_rasd_submission_form')

    @http.route('/rasd-form-submit', type='http', methods=['POST'], auth='public', website=True, csrf=False)
    def handle_submission_form(self, **post):
        """
        Handle the submission of the form and create records.
        """
        try:
            # Verify reCAPTCHA with Google
            recaptcha_response = post.get('g-recaptcha-response')
            secret_key = "6LfX9IwqAAAAAKVJ6umlbsKshCcTCDebLXc5ck2o"  # Replace with your reCAPTCHA secret key
            verify_url = "https://www.google.com/recaptcha/api/siteverify"
            payload = {
                'secret': secret_key,
                'response': recaptcha_response,
                'remoteip': request.httprequest.remote_addr,  # Optional
            }
            response = requests.post(verify_url, data=payload)
            result = response.json()

            # Debugging
            _logger.info("reCAPTCHA Validation Response: %s", result)

            # Check if reCAPTCHA verification passed
            if not result.get('success'):
                _logger.warning("reCAPTCHA validation failed: %s", result.get('error-codes', []))
                return request.render("rasd_forms.rasd_form_error", {
                    'error': "Captcha validation failed. Please try again."
                })

            ############################
            # Search for an existing RasdForm record based on the ID number only
            existing_form = request.env['rasd.form'].sudo().search([('id_number', '=', post.get('id_number'))], limit=1)

            if existing_form:
                rasd_form = existing_form
            else:
                # Create a new RasdForm record if no existing record is found
                rasd_form = request.env['rasd.form'].sudo().create({
                    'reporter_name': post.get('reporter_name'),
                    'id_number': post.get('id_number'),
                    'address': post.get('address'),
                    'email': post.get('email'),
                    'phone': post.get('phone'),
                    'report_type': post.get('report_type'),
                    'description': post.get('description'),
                    'total_estimated_value': post.get('total_estimated_value'),
                })

            # Handling specific loss type logic based on the report type
            if 'personal' in post.get('report_type', []):  # Check if personal loss is selected
                personal_loss = request.env['personal.loss'].sudo().create({
                    'rasd_form_id': rasd_form.id,
                    'name': post.get('name'),
                    'phone': post.get('phone'),
                    'email': post.get('email'),
                    'property_type': post.get('property_type'),
                    'estimated_value': post.get('personal_estimated_value'),
                    'description': post.get('description'),
                })
                files = request.httprequest.files.getlist('personal_upload')
                self.process_uploads(files, 'personal.loss', personal_loss.id)

            elif 'institutional' in post.get('report_type', []):  # Check if institutional loss is selected
                institutional_loss = request.env['institutional.loss'].sudo().create({
                    'rasd_form_id': rasd_form.id,
                    'institution_name': post.get('institution_name'),
                    'institution_type': post.get('institution_type'),
                    'contact_person': post.get('contact_person'),
                    'estimated_value': post.get('institution_estimated_value'),
                    'estimated_loss_percentage': post.get('estimated_loss_percentage'),
                    'description': post.get('description'),
                })
                files = request.httprequest.files.getlist('institutional_upload')
                self.process_uploads(files, 'institutional.loss', institutional_loss.id)

            elif 'infrastructure' in post.get('report_type', []):  # Check if infrastructure loss is selected
                infrastructural_loss = request.env['infrastructure.loss'].sudo().create({
                    'rasd_form_id': rasd_form.id,
                    'infrastructure_name': post.get('infrastructure_name'),
                    'damage_level': post.get('damage_level'),
                    'infrastructure_type': post.get('infrastructure_type'),
                    'estimated_cost': post.get('infrastructure_estimated_cost'),
                    'description': post.get('description'),
                    'infra_contact_person': post.get('infra_contact_person'),
                    'estimated_loss_percentage': post.get('estimated_loss_percentage'),
                })
                files = request.httprequest.files.getlist('infrastructure_upload')
                self.process_uploads(files, 'infrastructure.loss', infrastructural_loss.id)

            # Render confirmation page or handle errors
            # Assuming this logic is part of a larger try-except block or similar error handling structure.
            return request.render('rasd_forms.rasd_form_confirmation', {})

        except Exception as e:
            # Render error page with the exception message
            return request.render('rasd_forms.rasd_form_error', {'error': str(e)})

