from odoo import http
from odoo.http import request
import requests  # Ensure this import is added

class RasdReportController(http.Controller):
    # Route to display the search form
    @http.route('/report-search', type='http', auth="public", website=True)
    def show_search_form(self, **kwargs):
        # Render the form using 'search_form_template'
        return request.render('rasd_forms.search_form_template')  # Replace 'module_name' with your actual module name

    # Existing POST route for handling the form submission
    @http.route('/search-reports', type='http', auth="public", methods=['POST'], website=True)
    def search_reports(self, **post):
        recaptcha_response = post.get('g-recaptcha-response')
        secret_key = '6LfX9IwqAAAAAKVJ6umlbsKshCcTCDebLXc5ck2o'
        url = "https://www.google.com/recaptcha/api/siteverify"
        payload = {
            'secret': secret_key,
            'response': recaptcha_response
        }
        response = requests.post(url, data=payload)
        result = response.json()
        if not result.get('success'):  # reCAPTCHA verification failed
            error = "Invalid reCAPTCHA. Please try again."
            return request.render('rasd_forms.search_form_template', {'error': error})

        id_number = post.get('id_number')
        email = post.get('email')
        
        # Search for reports matching the ID number and email
        reports = request.env['rasd.form'].sudo().search([
            ('id_number', '=', id_number),
            ('email', '=', email)
        ])
        
        if reports:
            # Prepare data to display
            results = []
            for report in reports:
                report_data = {
                    'type': report.report_type,
                    'status': report.status,
                    'description': report.description,
                    'date_reported': report.date_reported.strftime('%Y-%m-%d'),
                    'estimated_value': report.total_estimated_value,
                    'additional_info': report.gps_location or 'N/A',  # Example of additional data
                }
                results.append(report_data)
            return request.render('rasd_forms.search_results', {'results': results})
        else:
            return request.render('rasd_forms.no_results', {})

# Note: Make sure 'module_name.search_form_template' accurately reflects your module's name and the template's XML ID.

