from odoo import api, fields, models
from odoo.exceptions import ValidationError


class RasdForm(models.Model):
    _name = 'rasd.form'
    _description = 'Rasd Central Form'

    # Basic Information
    name = fields.Char(string="Report Identifier", readonly=True, default='New')
    reporter_name = fields.Char(string="Reporter Name", required=True)
    id_number = fields.Char(string="National ID/Passport/Driving License No.")
    address = fields.Text(string="Address")
    email = fields.Char(string="Email Address")
    phone = fields.Char(string="Phone Number")

    # Report Type (Personal, Institutional, Infrastructure)
    report_type = fields.Selection([
        ('personal', 'Personal Loss'),
        ('institutional', 'Institutional Loss'),
        ('infrastructure', 'Infrastructural Loss')
    ], string="Report Type", required=True)

    # Loss Details
    gps_location = fields.Char(string="GPS Location")
    description = fields.Text(string="General Description")
    date_reported = fields.Date(string="Date Reported", default=fields.Date.today)
    status = fields.Selection([
        ('draft', 'Draft'),
        ('submitted', 'Submitted'),
        ('review', 'Under Review'),
        ('approved', 'Approved')
    ], string="Status", default='draft')
    total_estimated_value = fields.Float(string="Total Estimated Loss Value", default=0.0)

    # Relationships with Loss Types
    personal_loss_ids = fields.One2many('personal.loss', 'rasd_form_id', string="Personal Loss Reports")
    institutional_loss_ids = fields.One2many('institutional.loss', 'rasd_form_id', string="Institutional Loss Reports")
    infrastructural_loss_ids = fields.One2many('infrastructure.loss', 'rasd_form_id', string="Infrastructural Loss Reports")


class PersonalLoss(models.Model):
    _name = 'personal.loss'
    _description = 'Personal Loss Form'

    name = fields.Char(string="The affected person")
    phone = fields.Char(string="Phone Number")
    email = fields.Char(string="Email Address")
    rasd_form_id = fields.Many2one('rasd.form', string="Rasd Form", ondelete='cascade')
    property_type = fields.Char(string="Property Type")
    estimated_value = fields.Float(string="Estimated Loss Value")
    description = fields.Text(string="Description")
    personal_upload = fields.One2many(
        'ir.attachment', 'res_id',
        domain=[('res_model', '=', 'personal.loss')],
        string="Photos"
    )


class InstitutionalLoss(models.Model):
    _name = 'institutional.loss'
    _description = 'Institutional Loss Form'

    rasd_form_id = fields.Many2one('rasd.form', string="Rasd Form", ondelete='cascade')
    institution_name = fields.Char(string="Institution Name", required=True)
    institution_type = fields.Selection([
        ('hospital', 'Hospital'),
        ('school', 'School'),
        ('factory', 'Factory'),
        ('government', 'Government Facility')
    ], string="Institution Type")
    contact_person = fields.Char(string="Contact Person")
    estimated_value = fields.Float(string="Estimated Loss Value")
    description = fields.Text(string="Description")
    estimated_loss_percentage = fields.Float(string="Estimated Loss Percentage")
    institutional_upload = fields.One2many(
        'ir.attachment', 'res_id',
        domain=[('res_model', '=', 'institutional.loss')],
        string="Photos"
    )


class InfrastructureLoss(models.Model):
    _name = 'infrastructure.loss'
    _description = 'Infrastructural Loss Form'

    rasd_form_id = fields.Many2one('rasd.form', string="Rasd Form", ondelete='cascade')
    infrastructure_name = fields.Char(string="Infrastructure Name", required=True)
    damage_level = fields.Selection([
        ('minor', 'Minor'),
        ('moderate', 'Moderate'),
        ('severe', 'Severe'),
        ('complete', 'Complete Destruction')
    ], string="Damage Level")
    infrastructure_type = fields.Selection([
        ('road', 'Road'),
        ('bridge', 'Bridge'),
        ('electric_station', 'Electric Station'),
        ('water_facility', 'Water Facility'),
        ('telecom_tower', 'Telecommunication Tower'),
        ('port', 'Port'),
        ('railway', 'Railway'),
        ('airport', 'Airport'),
        ('building', 'Building'),
        ('dam', 'Dam')
    ], string="Infrastructure Type")
    estimated_cost = fields.Float(string="Estimated Repair Cost")
    description = fields.Text(string="Description")
    estimated_loss_percentage = fields.Float(string="Estimated Loss Percentage")
    infra_contact_person = fields.Char(string="Contact Person")
    infrastructure_upload = fields.One2many(
        'ir.attachment', 'res_id',
        domain=[('res_model', '=', 'infrastructure.loss')],
        string="Photos"
    )

