// Import the required Odoo module
const { _t } = require('web.core');

document.addEventListener('DOMContentLoaded', function () {
    const reportTypeSelect = document.getElementById('report_type');
    const conditionalFieldsContainer = document.getElementById('conditional_fields_container');

    const sections = {
        personal: `
            <div class="section-title">${_t("Personal Loss Details")}</div>
            <div class="form-group">
                <label for="name">${_t("The Victim")}</label>
                <input type="text" name="name" id="name" class="form-control" placeholder="${_t("Enter Victim Name")}" />
            </div>
            <div class="form-group">
                <label for="phone">${_t("Phone")}</label>
                <input type="text" name="phone" id="phone" class="form-control" placeholder="${_t("Enter Victim Phone")}" />
            </div>
            <div class="form-group">
                <label for="email">${_t("Email address")}</label>
                <input type="text" name="email" id="email" class="form-control" placeholder="${_t("Enter Email address")}" />
            </div>
            <div class="form-group">
                <label for="personal_estimated_value">${_t("Estimated Loss Value")}</label>
                <input type="number" name="personal_estimated_value" id="personal_estimated_value" class="form-control" placeholder="${_t("Enter estimated loss value")}" />
            </div>
            <div class="form-group">
                <label for="description">${_t("Description")}</label>
                <textarea type="text" name="description" id="description" class="form-control" placeholder="${_t("Enter the Description")}"></textarea>
            </div>
            <div class="form-group">
                <label for="personal_upload">${_t("Upload Photos")}</label>
                <div class="drop-zone">
                    ${_t("Drag and drop files here or click to upload")}
                    <input type="file" name="personal_upload" multiple="1" class="form-control-file" style="display: none;" />
                    <ul class="file-list"></ul>
                </div>
            </div>
        `,
        // Add similar sections for institutional and infrastructure as shown in your original JavaScript
    };

    reportTypeSelect.addEventListener('change', function () {
        conditionalFieldsContainer.innerHTML = sections[this.value] || '';
        initializeDropZones();
    });

    function initializeDropZones() {
        const dropZones = document.querySelectorAll('.drop-zone');
        dropZones.forEach(zone => {
            const fileInput = zone.querySelector('input[type="file"]');
            const fileList = zone.querySelector('.file-list');
            zone.addEventListener('click', () => fileInput.click());
            zone.addEventListener('dragover', e => {
                e.preventDefault();
                zone.classList.add('dragover');
            });
            zone.addEventListener('dragleave', () => zone.classList.remove('dragover'));
            zone.addEventListener('drop', e => {
                e.preventDefault();
                zone.classList.remove('dragover');
                const dataTransfer = new DataTransfer();
                Array.from(fileInput.files).forEach(file => dataTransfer.items.add(file));
                Array.from(e.dataTransfer.files).forEach(file => dataTransfer.items.add(file));
                fileInput.files = dataTransfer.files;
                displayFiles(fileInput.files, fileList);
            });
            fileInput.addEventListener('change', () => displayFiles(fileInput.files, fileList));
            function displayFiles(files, listContainer) {
                listContainer.innerHTML = '';
                Array.from(files).forEach(file => {
                    const listItem = document.createElement('li');
                    listItem.textContent = file.name;
                    listContainer.appendChild(listItem);
                });
            }
        });
    }
});
